==> nextcloud-28.0.3.tgz: nextcloud/apps/password_policy/l10n/lv.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Parole ir vien no 1,000,000 izplatītākajām parolēm. Lūdzu, padari to unikālu.",
    "Password is present in compromised password list. Please choose a different password." : "Parole atrodas uzlausto paroļu sarakstā. Lūdzu izvēlies citu paroli.",
    "Password needs to contain at least one numeric character." : "Parolē ir jābūt vismaz vienam skaitlim.",
    "Password needs to contain at least one special character." : "Parolei jāsatur vismaz vienu speciālo rakstzīmi.",
    "Password needs to contain at least one lower and one upper case character." : "Parolē ir jābūt vismaz vienam mazajam un vienam lielajam burtam.",
    "Password policy" : "Paroles politika",
    "Allows admins to configure a password policy" : "Ļauj administrātoriem uzstādīt paroļu politiku",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Atļaut administrātoram uzstādīt noteiktus paroles uzstādījumus, piem. minimālo paroles garumu",
    "Forbid common passwords" : "Aizliegt kopīgas paroles",
    "Enforce upper and lower case characters" : "Uzspiest lielos un mazos burtus",
    "Enforce numeric characters" : "Uzspiest skaitļus",
    "Enforce special characters" : "Uzspiest speciālos simbolus",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Pārbaudīt paroli pret uzlaustajām parolēm no haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Šis izveido hašu no paroles pirmajām 5 rakstzīmēm un pārbauda to pret haveibeenpwned.com, lai saņemtu paroļu sarakstu kas sākas ar tām rakstzīmēm. Tad tas pārbauda pilnos paroles hešus pret dabūto sarakstu.",
    "Unknown error" : "Nezināma kļūda",
    "Settings saved" : "Iestatījumi saglabāti",
    "Saved" : "Saglabāts"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-29.0.5.tgz: nextcloud/apps/password_policy/l10n/lv.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Parole ir vien no 1,000,000 izplatītākajām parolēm. Lūdzu, padari to unikālu.",
    "Password is present in compromised password list. Please choose a different password." : "Parole atrodas uzlausto paroļu sarakstā. Lūdzu izvēlies citu paroli.",
    "Password needs to contain at least one numeric character." : "Parolē ir jābūt vismaz vienam skaitlim.",
    "Password needs to contain at least one special character." : "Parolei jāsatur vismaz vienu speciālo rakstzīmi.",
    "Password needs to contain at least one lower and one upper case character." : "Parolē ir jābūt vismaz vienam mazajam un vienam lielajam burtam.",
    "Password policy" : "Paroles politika",
    "Allows admins to configure a password policy" : "Ļauj administrātoriem uzstādīt paroļu politiku",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Ļauj pārvaldītājam pievienot noteiktus paroles priekšnosacījumus, piemēram, uzspiest mazāko pieļaujamo garumu",
    "Forbid common passwords" : "Aizliegt kopīgas paroles",
    "Enforce upper and lower case characters" : "Uzspiest lielos un mazos burtus",
    "Enforce numeric characters" : "Uzspiest skaitļus",
    "Enforce special characters" : "Uzspiest speciālos simbolus",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Pārbaudīt paroli pret uzlaustajām parolēm no haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Šis izveido hašu no paroles pirmajām 5 rakstzīmēm un pārbauda to pret haveibeenpwned.com, lai saņemtu paroļu sarakstu kas sākas ar tām rakstzīmēm. Tad tas pārbauda pilnos paroles hešus pret dabūto sarakstu.",
    "Unknown error" : "Nezināma kļūda",
    "Settings saved" : "Iestatījumi saglabāti"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
